summaryrefslogtreecommitdiff
path: root/premake5.lua
diff options
context:
space:
mode:
authorTriang3l <triang3l@yandex.ru>2021-09-12 14:10:36 +0300
committerTriang3l <triang3l@yandex.ru>2021-09-12 14:10:36 +0300
commitecccd02f8a8db84f070aacac09ab0cb3c6feb196 (patch)
treeea38d1f87042a7ea8717f04fe4850193d3b39333 /premake5.lua
parent9bb104b354871c34802f28faaa4e9f3b7a8abcc4 (diff)
parent6241b4f907ef09dd07411f84515adc9b9aee1c99 (diff)
Merge branch 'master' into vulkan
Diffstat (limited to 'premake5.lua')
-rw-r--r--premake5.lua12
1 files changed, 11 insertions, 1 deletions
diff --git a/premake5.lua b/premake5.lua
index 8ea9ce93c..3c2c9d49d 100644
--- a/premake5.lua
+++ b/premake5.lua
@@ -189,6 +189,12 @@ filter("platforms:Windows")
"bcrypt",
})
+-- Embed the manifest for things like dependencies and DPI awareness.
+filter({"platforms:Windows", "kind:ConsoleApp or WindowedApp"})
+ files({
+ "src/xenia/base/app_win32.manifest"
+ })
+
-- Create scratch/ path
if not os.isdir("scratch") then
os.mkdir("scratch")
@@ -242,9 +248,13 @@ workspace("xenia")
include("third_party/SDL2.lua")
end
- -- Disable treating warnings as fatal errors for all third party projects:
+ -- Disable treating warnings as fatal errors for all third party projects, as
+ -- well as other things relevant only to Xenia itself.
for _, prj in ipairs(premake.api.scope.current.solution.projects) do
project(prj.name)
+ removefiles({
+ "src/xenia/base/app_win32.manifest"
+ })
removeflags({
"FatalWarnings",
})